# FAN-C: Framework for the ANalysis of C-like data

FAN-C provides a pipeline for analysing Hi-C data starting at mapped paired-end sequencing reads.

![](https://raw.githubusercontent.com/vaquerizaslab/fanc/main/docsrc/fnc-overview.png)

Please check out the documentation at https://fan-c.readthedocs.io/en/latest/ for detailed installation and usage
instructions!

FAN-C is published in [Genome Biology](https://genomebiology.biomedcentral.com/articles/10.1186/s13059-020-02215-9). 
If you use it in your research, please cite it as:

```
Kruse, K., Hug, C.B. & Vaquerizas, J.M. 
FAN-C: a feature-rich framework for the analysis and visualisation of chromosome conformation capture data. 
Genome Biol 21, 303 (2020). 
https://doi.org/10.1186/s13059-020-02215-9
```

If you like FAN-C, come and say "Hi" on Twitter! [@kaukrise](https://twitter.com/kaukrise) [@vaquerizas_lab](https://twitter.com/vaquerizas_lab)


## News

We are currently working on a much faster version of FAN-C with speedups of more than 10x for many commands. 
If you want to try it out and give us some feedback, please check out the `dev` channel. You can find instructions 
in the [docs](https://fan-c.readthedocs.io/en/latest/getting_started.html#installation).
Note that this is 
not an official release yet, however, and you will likely encounter unresolved issues, which we kindly ask 
you to report here, on GitHub! Thanks!
